==> Enbld-0.7013.tar.gz: Enbld-0.7013/lib/Enbld/Command/List.pm <==
package Enbld::Command::List;

use 5.012;
use warnings;

use parent qw/Enbld::Command/;

use Encode;

require Enbld::Home;
require Enbld::App::Configuration;

sub do {
    my $self = shift;

    my $target_name = shift @{ $self->{argv} };

	if ( $target_name ) {

		$self->list_target_installed_version( $target_name );

	} else {
		$self->list_all_installed;
	}
}

sub list_all_installed {
	my $self = shift;

    Enbld::Home->initialize;
    Enbld::App::Configuration->read_file;

    my $collection = Enbld::App::Configuration->config;

    if ( ! keys %{ $collection } ) {
        say "Nothing is installed yet.";
    }

    foreach my $name ( sort keys %{ $collection } ) {
        my $config = Enbld::App::Configuration->search_config( $name );
        
        my $line = $name . ' ' x 15;
        
        print substr( $name . ' ' x 15 , 0, 15 );

        my $version;
        if ( $config->enabled ) {
            $version = $config->enabled;
        } else {
            $version = 'Not enabled now...';
        }

        print substr( $version . ' ' x 20, 0, 20 );

        if ( $config->condition->annotation ) {
            print encode( 'UTF-8', $config->condition->annotation );
        }

        print "\n";
    }

    return $self;
}

sub list_target_installed_version {
	my $self = shift;
	my $target_name = shift;

    Enbld::Home->initialize;
    Enbld::App::Configuration->read_file;

    my $config = Enbld::App::Configuration->search_config( $target_name );

    if ( ! $config ) {
        require Enbld::Error;
        die Enbld::Error->new( "Target '$target_name' is not installed yet.\n" );
    }

    for my $installed ( sort keys %{ $config->installed } ) {
        print $installed . "\n";
    }



	return $self;
}

1;

==> Enbld-0.7028.tar.gz: Enbld-0.7028/lib/Enbld/Command/List.pm <==
package Enbld::Command::List;

use 5.012;
use warnings;

use parent qw/Enbld::Command/;

use Encode;

require Enbld::Home;
require Enbld::App::Configuration;

sub do {
    my $self = shift;

    my $target_name = shift @{ $self->{argv} };

	if ( $target_name ) {

		$self->list_target_installed_version( $target_name );

	} else {
		$self->list_all_installed;
	}
}

sub list_all_installed {
	my $self = shift;

    Enbld::Home->initialize;
    Enbld::App::Configuration->read_file;

    my $collection = Enbld::App::Configuration->config;

    if ( ! keys %{ $collection } ) {
        say "Nothing is installed yet.";
    }

    foreach my $name ( sort keys %{ $collection } ) {
        my $config = Enbld::App::Configuration->search_config( $name );
        
        my $line = $name . ' ' x 15;
        
        print substr( $name . ' ' x 15 , 0, 15 );

        my $version;
        if ( $config->enabled ) {
            $version = $config->enabled;
        } else {
            $version = 'Not enabled now...';
        }

        print substr( $version . ' ' x 20, 0, 20 );

        if ( $config->enabled && $config->condition->annotation ) {
            print encode( 'UTF-8', $config->condition->annotation );
        }

        print "\n";
    }

    return $self;
}

sub list_target_installed_version {
	my $self = shift;
	my $target_name = shift;

    Enbld::Home->initialize;
    Enbld::App::Configuration->read_file;

    my $config = Enbld::App::Configuration->search_config( $target_name );

    if ( ! $config ) {
        require Enbld::Error;
        die Enbld::Error->new( "Target '$target_name' is not installed yet.\n" );
    }

    for my $installed ( sort keys %{ $config->installed } ) {
        print $installed . "\n";
    }



	return $self;
}

1;
